/* ###################################################################
**     Filename    : mqx_tasks.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : Events
**     Version     : Driver 01.00
**     Compiler    : GNU C Compiler
**     Date/Time   : 2013-05-20, 14:22, # CodeGen: 0
**     Abstract    :
**         This is user's event module.
**         Put your event handler code here.
**     Settings    :
**     Contents    :
**         Podazanie_task - void Podazanie_task(uint32_t task_init_data);
**
** ###################################################################*/
/*!
** @file mqx_tasks.c
** @version 01.00
** @brief
**         This is user's event module.
**         Put your event handler code here.
*/         
/*!
**  @addtogroup mqx_tasks_module mqx_tasks module documentation
**  @{
*/         
/* MODULE mqx_tasks */

#include "Cpu.h"
#include "Events.h"
#include "mqx_tasks.h"

#ifdef __cplusplus
extern "C" {
#endif 

/**************/
static int granica = 8000;
static int kp = 2;
static int kd = 1;
static int vnom = 30;
/**************/

static int pomiary[6];
static boolean flaga[6];
static int czujniki_waga[6];

static long long int suma = 0;
static int blad = 0;
static int blad_poprzedni = 0;
static int ile = 0;
static int poprzednia = 0;
static int aktualna = 0;

static int zmiana = 0;

static int d = 0;

static int lewy = 0;
static int prawy = 0;

static int counter = 0;
static int i = 0;

static double motorA = 0;
static double motorB = 0;

static boolean kierunek = 0;


/* User includes (#include below this line is not maintained by Processor Expert) */
	LDD_TDeviceData *DIRADeviceData = NULL;
	LDD_TDeviceData *DIRBDeviceData = NULL;
	LDD_TDeviceData *BRAKEADeviceData = NULL;
	LDD_TDeviceData *BRAKEBDeviceData = NULL;
	LDD_TDeviceData *PWMADeviceData = NULL;
	LDD_TDeviceData *PWMBDeviceData = NULL;
	LDD_TDeviceData *AD1DeviceData = NULL;
/*
** ===================================================================
**     Event       :  Podazanie_task (module mqx_tasks)
**
**     Component   :  Task1 [MQXLite_task]
**     Description :
**         MQX task routine. The routine is generated into mqx_tasks.c
**         file.
**     Parameters  :
**         NAME            - DESCRIPTION
**         task_init_data  - 
**     Returns     : Nothing
** ===================================================================
*/
	
void Podazanie_task(uint32_t task_init_data)
{
	DIRADeviceData = DIRA_Init(NULL);
	DIRBDeviceData = DIRB_Init(NULL);
	BRAKEADeviceData = BRAKEA_Init(NULL);
	BRAKEBDeviceData = BRAKEB_Init(NULL);
	PWMADeviceData = PWMA_Init(NULL);
	PWMBDeviceData = PWMB_Init(NULL);
	 
	//AD1DeviceData = AD1_Init();
	 
	DIRA_SetVal(DIRADeviceData);
	DIRB_SetVal(DIRBDeviceData);
	BRAKEA_ClrVal(BRAKEADeviceData);
	BRAKEB_ClrVal(BRAKEBDeviceData);
	
	PWMA_SetDutyUS(PWMADeviceData, 1365.333);//1365.333
	PWMB_SetDutyUS(PWMBDeviceData, 1365.333);//1365.333

		
  while(1) {
    counter++;
       
    PID();

  }
}

void CzytajADC()
{	
    (void)AD1_MeasureChan(TRUE, 0);
    (void)AD1_MeasureChan(TRUE, 1);
    (void)AD1_MeasureChan(TRUE, 2);
    (void)AD1_MeasureChan(TRUE, 3);
    (void)AD1_MeasureChan(TRUE, 4);
    (void)AD1_MeasureChan(TRUE, 5);
    
    (void)AD1_GetChanValue16(0, &pomiary[4]);
    (void)AD1_GetChanValue16(1, &pomiary[3]);
    (void)AD1_GetChanValue16(2, &pomiary[2]);
    (void)AD1_GetChanValue16(3, &pomiary[1]);
    (void)AD1_GetChanValue16(4, &pomiary[5]);
    (void)AD1_GetChanValue16(5, &pomiary[0]);
    
    if (pomiary[0] > granica) {flaga[0] = 1;} else {flaga[0] = 0;}
    if (pomiary[1] > granica) {flaga[1] = 1;} else {flaga[1] = 0;}
    if (pomiary[2] > granica) {flaga[2] = 1;} else {flaga[2] = 0;}
    if (pomiary[3] > granica) {flaga[3] = 1;} else {flaga[3] = 0;}
    if (pomiary[4] > granica) {flaga[4] = 1;} else {flaga[4] = 0;}
    if (pomiary[5] > granica) {flaga[5] = 1;} else {flaga[5] = 0;}
    
	czujniki_waga[0] = -9;
	czujniki_waga[1] = -4;
	czujniki_waga[2] = -2;
	czujniki_waga[3] = 2;
	czujniki_waga[4] = 4;
	czujniki_waga[5] = 9;
	
}

void PID ()
{
	
	CzytajADC();
	suma = 0;
	ile = 0;
	
	poprzednia = aktualna;
	
	for (i = 0; i <= 6; i++) {
		if (flaga[i] == 1) {
			suma += czujniki_waga[i];
			ile++;
		}
	}
	
	if (ile == 6) {
		if (poprzednia > 0) {
			aktualna = 5;			
		}
		if (poprzednia < 0) {
			aktualna = -5;	
		}
	} else {
			aktualna = (suma/ile);
	}
	
	zmiana = 0;
	
	blad = 0 - aktualna;
	
	d = (blad-blad_poprzedni);
	
	zmiana = kp * blad + kd * d;
	
	lewy = 0;
	prawy = 0;
	
	if (ile == 0) { //zaden czujnik nie widzi linii
		
		if (kierunek == 1) {//ostatnio linia byla po prawej
			
			prawy = 0;
			lewy = vnom +20;
			
		} else { //ostatnio linia byla po lewej
			
			prawy = vnom +20;
			lewy = 0;
			
		}		
		
	} else {
		
		prawy = vnom + zmiana;
		lewy = vnom - zmiana;
		
		if (prawy > (vnom +20)) {
			prawy = vnom +20;
		}
		if (lewy > (vnom +20)) {
			lewy = vnom +20;
		}
		if (prawy < -(vnom +20)) {
			prawy = -(vnom +20);
		}
		if (lewy < -(vnom +20)) {
			lewy = -(vnom +20);
		}
		
		if (prawy > lewy) {			
			kierunek = 0;			
		} else {			
			kierunek = 1;			
		}
		
	}
	
	silniki (lewy, prawy);
	blad_poprzedni = blad;	
	
}

void silniki (int lewyf, int prawyf) {
	
	//lewy i prawy podany w %
	//0% to 1365.333 us
	//100% to 0.020833 us
	//1% to 13.65333
	//99% to (100-99)*13.65333
	motorA = 0;
	motorB = 0;
	
	motorA = (100 - prawyf) * 13.65333;
	motorB = (100 - lewyf) * 13.65333;

	PWMA_SetDutyUS(PWMADeviceData, motorA);//1365.333 prawy
	PWMB_SetDutyUS(PWMBDeviceData, motorB);//1365.333	lewy
	
}

/* END mqx_tasks */

#ifdef __cplusplus
}  /* extern "C" */
#endif 

/*!
** @}
*/
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.2 [05.06]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
